;+
;	NAME:	RngAz_to_LL
;
; PURPOSE:
;	This function  longitude and latitude of points along a great circle given the range and azimuth.
;
; CATEGORY:
;	Mapping
;
; CALLING SEQUENCE:
;
;	Result = RngAz_To_LL(Lon0,Lat0, Range, Azimuth)
;
;
; INPUTS
;	Lon0  The longitude of the starting point (must fall within -180. to 180.)
;	Lat0 The latitude of the starting point (must fall within -90, to 90.)
;	Range  The great circle distance from Lon0,Lat0 to Lon1, Lat1 in units of radius (meters default.)
;	Azimuth The azimuth direction from the starting point to finish in Degrees.
;
; KEYWORDS
;	RADIANS
;	Set this keyword to indicate that the input values are in radians.  Setting this value
;	cause the output azimuth values to be in radians.
;
;	ARC
;	Set this keyword to a non-zero value to indicate that the Range is given in arc length (radians) rather
;	than linear units.
;
;	RADIUS
;	Set this keyword to the desired raduis of the sphere.   The default value is
;	is the  equatorial radius for the GRS 80 model for the Earth ellipsoid.
;	The WGS84 (NAD 83) map datum uses the same radius.
;	Default value (GRS 80) =  6378137. meters (Source = Snyder, Chapter 3, Table 1)
;
;	CLARKE
;	Set this keyword to a non-zero value to use the equatorial radius
;	for the Clarke 1866 model for the ellipsoid.
;	NAD27 mapdatum uses the same value.
;	Value (Clarke 1866) =  6378206.4 meters (source = Snyder, Chapter 3, Table 1)
;	If this keyword is not set, the GRS 80 value is used.   This keyword has no effect if
;	the radius keyword is set.
;
;	NPOINTS
;	Set this keyword to the number of points to interpolate along the great circle.  Default = 1 (the endpoint.)
;
; DISCUSSION
;	Snyder  (Chapter 5) shows two equations "to find the latitude Lat1) and longitude (Lon1) at a given arc distance (c)
;	and Azimuth (Az) east of north from" Lon0,Lat0.
;
;	(5-5) Lat1 = asin( sin(Lat0)*cos(c) + cos(Lat0)*sin(c)*cos(Az) )
;
;	(5-6) Lon1 = Lon0 + $
;		atan( sin(c)*sin(Az)/ ( cos(Lat0)*cos(c) - sin(Lat0)*sin(c)*cos(Az) ) )
;
;
; REFERENCE
;  Snyder, John P. (1987), "Map Projections-A Working Manual",
;	 U.S. Geological Survey Professional Paper 1395,
;	 U.S.Government Printing Office, Washington, D.C.
;
;	EXAMPLE
;	IDL> LL = RngAz_to_LL(-70,45,792994.72 ,9.9988395,npoints = 3)
;IDL> print,LL
;      -70.000000       45.000000
;      -69.067178       48.504064
;      -67.995799       51.999472
;
; MODIFICATION HISTORY:
;	This routine was inspired by Great_Circle (Liam Gumley, 1999) and Compass (Paul Ricchiazzi, 1993).
; 	Written by:	Ben Tupper  Dec 11, 1999
;	Pemaquid River Company
;	email: pemaquidriver@tidewater.net
;	tel:  (207) 563 - 1048
;   248 Lower Round Pond Road
;	POB 106
;	Bristol, ME 04539-0106
;
;
;-

FUNCTION RngAz_to_LL, LonStart, LatStart, Range, Azimuth, $
	nPoints = nPoints,$
	Arc = Arc,$
	Radius = Radius,$
	Clarke = Clarke,$
	Radians = Radians


On_Error, 2

If N_elements(nPoints) EQ 0 Then nPoints = 1L

	; convert the longitude/latitude values into radians unless otherwise told
If N_elements(Radians) EQ 0 Then Begin

	Lon0 = LonStart*!DtoR
	Lat0 = LatStart*!DtoR

EndIf Else Begin

	Lon0 = LonStart
	Lat0 = LatStart

EndElse

	;set the radius of the sphere
If n_elements(Radius) EQ 0 Then $
	If N_Elements(Clarke) EQ 0 Then $
		Radius =  6378137. Else Radius = 6378206.4
Radius = Double(Radius)

	;switch range to arc length (radians)  unless told to do otherwise
If N_Elements(Arc) EQ 0 Then c = Double(Range)/Radius Else c = Double(Range)

	;switch Azimuth to radians unless Radians keyword is set
If N_elements(Radians) EQ 0 Then Az = Double(Azimuth*!DtoR) Else Az =Double( Azimuth)

	;if nPoints GT 1 then switch c to a vector
If nPoints GT 1 Then Begin


	c = Dindgen(nPoints) / Double((nPoints-1)) * c
	Az 	= Replicate(Az, nPoints)

EndIf


Lon1 = Lon0 + $
		atan( sin(c)*sin(Az)/ ( cos(Lat0)*cos(c) - sin(Lat0)*sin(c)*cos(Az) ) )

Lat1 = asin( sin(Lat0)*cos(c) + cos(Lat0)*sin(c)*cos(Az) )


	;convert back to degrees unless told otherwise
If N_elements(Radians) EQ 0 Then  Begin

 	Lon1 = Lon1* !RaDeg
	Lat1 = Lat1*!RaDeg

EndIf

Return, Transpose([ [lon1],[lat1]])
END

